==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/DeleteRecommenderConfigurationRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteRecommenderConfigurationRequest(
    recommenderId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest = {
    import DeleteRecommenderConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
      .builder()
      .recommenderId(__string.unwrap(recommenderId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest.ReadOnly =
    zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest
      .wrap(buildAwsValue())
}
object DeleteRecommenderConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest =
      zio.aws.pinpoint.model
        .DeleteRecommenderConfigurationRequest(recommenderId)
    def recommenderId: __string
    def getRecommenderId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(recommenderId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
  ) extends zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest.ReadOnly {
    override val recommenderId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.recommenderId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
  ): zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/DeleteRecommenderConfigurationRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteRecommenderConfigurationRequest(
    recommenderId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest = {
    import DeleteRecommenderConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
      .builder()
      .recommenderId(recommenderId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest.ReadOnly =
    zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest
      .wrap(buildAwsValue())
}
object DeleteRecommenderConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest =
      zio.aws.pinpoint.model
        .DeleteRecommenderConfigurationRequest(recommenderId)
    def recommenderId: __string
    def getRecommenderId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(recommenderId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
  ) extends zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest.ReadOnly {
    override val recommenderId: __string = impl.recommenderId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteRecommenderConfigurationRequest
  ): zio.aws.pinpoint.model.DeleteRecommenderConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
